@@ -15,6 +15,7 @@ from . import time_series
 from . import df_utils
 from . import beps_data_generator
 from . import nanonis
+from . import image
 
 from .be_odf import BEodfTranslator
 from .be_odf_relaxation import BEodfRelaxationTranslator
@@ -24,7 +25,6 @@ from .gmode_iv import GIVTranslator
 from .gmode_line import GLineTranslator
 from .gmode_tune import GTuneTranslator
 from .igor_ibw import IgorIBWTranslator
-from pycroscopy.core.io.image import ImageTranslator
 from .ndata import NDataTranslator
 from .tr_kpfm import TRKPFMTranslator
 from .oneview import OneViewTranslator
@@ -35,9 +35,10 @@ from .bruker_afm import BrukerAFMTranslator
 from .beps_data_generator import FakeBEPSGenerator
 from .labview_h5_patcher import LabViewH5Patcher
 from .nanonis import NanonisTranslator
+from .image import ImageTranslator
 
 __all__ = ['BEodfTranslator', 'BEPSndfTranslator', 'BEodfRelaxationTranslator',
            'GIVTranslator', 'GLineTranslator', 'GTuneTranslator', 'GDMTranslator', 'PtychographyTranslator',
            'SporcTranslator', 'MovieTranslator', 'IgorIBWTranslator',
-           'OneViewTranslator', 'ImageTranslator', 'NDataTranslator', 'FakeBEPSGenerator',
-           'LabViewH5Patcher', 'TRKPFMTranslator', 'BrukerAFMTranslator']
+           'OneViewTranslator', 'NDataTranslator', 'FakeBEPSGenerator',
+           'LabViewH5Patcher', 'TRKPFMTranslator', 'BrukerAFMTranslator', 'ImageTranslator']
